pub trait DeepView {
type V;
// Required method
spec fn deep_view(&self) -> Self::V;
}Required Associated Types
Required Methods
Implementations on Foreign Types
Sourceimpl<'a, T: DeepView + Clone> DeepView for Cow<'a, [T]>
Available on crate feature alloc only.
impl<'a, T: DeepView + Clone> DeepView for Cow<'a, [T]>
Available on crate feature
alloc only.Sourceimpl<A0: DeepView, A1: DeepView, A2: DeepView, A3: DeepView, A4: DeepView> DeepView for (A0, A1, A2, A3, A4)
impl<A0: DeepView, A1: DeepView, A2: DeepView, A3: DeepView, A4: DeepView> DeepView for (A0, A1, A2, A3, A4)
Sourceimpl<A0: DeepView, A1: DeepView, A2: DeepView, A3: DeepView, A4: DeepView, A5: DeepView> DeepView for (A0, A1, A2, A3, A4, A5)
impl<A0: DeepView, A1: DeepView, A2: DeepView, A3: DeepView, A4: DeepView, A5: DeepView> DeepView for (A0, A1, A2, A3, A4, A5)
Sourceimpl<A0: DeepView, A1: DeepView, A2: DeepView, A3: DeepView, A4: DeepView, A5: DeepView, A6: DeepView> DeepView for (A0, A1, A2, A3, A4, A5, A6)
impl<A0: DeepView, A1: DeepView, A2: DeepView, A3: DeepView, A4: DeepView, A5: DeepView, A6: DeepView> DeepView for (A0, A1, A2, A3, A4, A5, A6)
Sourceimpl<A0: DeepView, A1: DeepView, A2: DeepView, A3: DeepView, A4: DeepView, A5: DeepView, A6: DeepView, A7: DeepView> DeepView for (A0, A1, A2, A3, A4, A5, A6, A7)
impl<A0: DeepView, A1: DeepView, A2: DeepView, A3: DeepView, A4: DeepView, A5: DeepView, A6: DeepView, A7: DeepView> DeepView for (A0, A1, A2, A3, A4, A5, A6, A7)
Sourceimpl<A0: DeepView, A1: DeepView, A2: DeepView, A3: DeepView, A4: DeepView, A5: DeepView, A6: DeepView, A7: DeepView, A8: DeepView> DeepView for (A0, A1, A2, A3, A4, A5, A6, A7, A8)
impl<A0: DeepView, A1: DeepView, A2: DeepView, A3: DeepView, A4: DeepView, A5: DeepView, A6: DeepView, A7: DeepView, A8: DeepView> DeepView for (A0, A1, A2, A3, A4, A5, A6, A7, A8)
type V = (<A0 as DeepView>::V, <A1 as DeepView>::V, <A2 as DeepView>::V, <A3 as DeepView>::V, <A4 as DeepView>::V, <A5 as DeepView>::V, <A6 as DeepView>::V, <A7 as DeepView>::V, <A8 as DeepView>::V)
fn deep_view( &self, ) -> (A0::V, A1::V, A2::V, A3::V, A4::V, A5::V, A6::V, A7::V, A8::V)
Sourceimpl<A0: DeepView, A1: DeepView, A2: DeepView, A3: DeepView, A4: DeepView, A5: DeepView, A6: DeepView, A7: DeepView, A8: DeepView, A9: DeepView> DeepView for (A0, A1, A2, A3, A4, A5, A6, A7, A8, A9)
impl<A0: DeepView, A1: DeepView, A2: DeepView, A3: DeepView, A4: DeepView, A5: DeepView, A6: DeepView, A7: DeepView, A8: DeepView, A9: DeepView> DeepView for (A0, A1, A2, A3, A4, A5, A6, A7, A8, A9)
type V = (<A0 as DeepView>::V, <A1 as DeepView>::V, <A2 as DeepView>::V, <A3 as DeepView>::V, <A4 as DeepView>::V, <A5 as DeepView>::V, <A6 as DeepView>::V, <A7 as DeepView>::V, <A8 as DeepView>::V, <A9 as DeepView>::V)
fn deep_view( &self, ) -> (A0::V, A1::V, A2::V, A3::V, A4::V, A5::V, A6::V, A7::V, A8::V, A9::V)
Sourceimpl<A0: DeepView, A1: DeepView, A2: DeepView, A3: DeepView, A4: DeepView, A5: DeepView, A6: DeepView, A7: DeepView, A8: DeepView, A9: DeepView, A10: DeepView> DeepView for (A0, A1, A2, A3, A4, A5, A6, A7, A8, A9, A10)
impl<A0: DeepView, A1: DeepView, A2: DeepView, A3: DeepView, A4: DeepView, A5: DeepView, A6: DeepView, A7: DeepView, A8: DeepView, A9: DeepView, A10: DeepView> DeepView for (A0, A1, A2, A3, A4, A5, A6, A7, A8, A9, A10)
type V = (<A0 as DeepView>::V, <A1 as DeepView>::V, <A2 as DeepView>::V, <A3 as DeepView>::V, <A4 as DeepView>::V, <A5 as DeepView>::V, <A6 as DeepView>::V, <A7 as DeepView>::V, <A8 as DeepView>::V, <A9 as DeepView>::V, <A10 as DeepView>::V)
fn deep_view( &self, ) -> (A0::V, A1::V, A2::V, A3::V, A4::V, A5::V, A6::V, A7::V, A8::V, A9::V, A10::V)
Sourceimpl<A0: DeepView, A1: DeepView, A2: DeepView, A3: DeepView, A4: DeepView, A5: DeepView, A6: DeepView, A7: DeepView, A8: DeepView, A9: DeepView, A10: DeepView, A11: DeepView> DeepView for (A0, A1, A2, A3, A4, A5, A6, A7, A8, A9, A10, A11)
impl<A0: DeepView, A1: DeepView, A2: DeepView, A3: DeepView, A4: DeepView, A5: DeepView, A6: DeepView, A7: DeepView, A8: DeepView, A9: DeepView, A10: DeepView, A11: DeepView> DeepView for (A0, A1, A2, A3, A4, A5, A6, A7, A8, A9, A10, A11)
type V = (<A0 as DeepView>::V, <A1 as DeepView>::V, <A2 as DeepView>::V, <A3 as DeepView>::V, <A4 as DeepView>::V, <A5 as DeepView>::V, <A6 as DeepView>::V, <A7 as DeepView>::V, <A8 as DeepView>::V, <A9 as DeepView>::V, <A10 as DeepView>::V, <A11 as DeepView>::V)
fn deep_view( &self, ) -> (A0::V, A1::V, A2::V, A3::V, A4::V, A5::V, A6::V, A7::V, A8::V, A9::V, A10::V, A11::V)
Sourceimpl<Key: DeepView, S, A: Allocator> DeepView for HashSet<Key, S, A>
Available on crate feature alloc and crate feature std and (verus_keep_ghost or crate feature allocator) only.
impl<Key: DeepView, S, A: Allocator> DeepView for HashSet<Key, S, A>
Available on crate feature
alloc and crate feature std and (verus_keep_ghost or crate feature allocator) only.Sourceimpl<Key: DeepView, Value: DeepView, A: Allocator + Clone> DeepView for BTreeMap<Key, Value, A>
impl<Key: DeepView, Value: DeepView, A: Allocator + Clone> DeepView for BTreeMap<Key, Value, A>
Sourceimpl<Key: DeepView, Value: DeepView, S, A: Allocator> DeepView for HashMap<Key, Value, S, A>
Available on crate feature alloc and crate feature std and (verus_keep_ghost or crate feature allocator) only.
impl<Key: DeepView, Value: DeepView, S, A: Allocator> DeepView for HashMap<Key, Value, S, A>
Available on crate feature
alloc and crate feature std and (verus_keep_ghost or crate feature allocator) only.Sourceimpl<T: DeepView, A: Allocator> DeepView for Vec<T, A>
Available on crate feature alloc and (verus_keep_ghost or crate feature allocator) only.
impl<T: DeepView, A: Allocator> DeepView for Vec<T, A>
Available on crate feature
alloc and (verus_keep_ghost or crate feature allocator) only.